# Crew Board Game

An in-progress implementation of the crew board-game with some helper scripts for an over-the-board (OTB) game.

## Installation

To install run the following command:

```
pip install crew_game
```

It is strongly recommended to install this package in a [virtual environment](https://docs.python.org/3/tutorial/venv.html)

## Development

This repo is packaged using [`flit`](https://flit.readthedocs.io/en/latest/). To get started with development, clone this repo and install with:

```
git clone https://github.com/chiraag/crew_game.git
flit install -s
```